@@ -24,11 +24,12 @@
 
 #include <KLocale>
 #include <KDebug>
-#include <KIconLoader>
 #include <KActionCollection>
 #include <KStandardAction>
 #include <KPluginFactory>
 
+#include <KoIcon.h>
+
 #include <formeditor/container.h>
 #include <formeditor/form.h>
 #include <formeditor/formIO.h>
@@ -38,8 +39,8 @@
 #include <core/kexi.h>
 #include <core/kexipart.h>
 #include <core/KexiMainWindowIface.h>
-#include <kexidb/utils.h>
-#include <kexidb/connection.h>
+#include <db/utils.h>
+#include <db/connection.h>
 #include <kexiutils/utils.h>
 #include <kexiutils/KexiCommandLinkButton.h>
 #include <widget/properties/KexiCustomPropertyFactory.h>
@@ -71,7 +72,7 @@
 #include "kexidbfactory.h"
 #include <widget/dataviewcommon/kexiformdataiteminterface.h>
 
-
+#include <QFontMetrics>
 //////////////////////////////////////////
 
 KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
@@ -80,7 +81,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
 {
     {
         KexiDataAwareWidgetInfo *wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("form");
+        wi->setIconName(koIconName("form"));
         wi->setClassName("KexiDBForm");
         wi->setName(i18n("Form"));
         wi->setNamePrefix(
@@ -93,7 +94,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
 #ifndef KEXI_NO_SUBFORM
     {
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("subform");
+        wi->setIconName(koIconName("subform"));
         wi->setClassName("KexiDBSubForm");
         wi->addAlternateClassName("KexiSubForm", true/*override*/); //older
         wi->setName(i18n("Sub Form"));
@@ -109,7 +110,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     {
         // inherited
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("lineedit");
+        wi->setIconName(koIconName("lineedit"));
         wi->setClassName("KexiDBLineEdit");
         wi->setParentFactoryName("stdwidgets");
         wi->setInheritedClassName("KLineEdit");
@@ -128,7 +129,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     {
         // inherited
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("textedit");
+        wi->setIconName(koIconName("textedit"));
         wi->setClassName("KexiDBTextEdit");
         wi->setParentFactoryName("stdwidgets");
         wi->setInheritedClassName("KTextEdit");
@@ -146,7 +147,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     }
     {
         KFormDesigner::WidgetInfo* wi = new KFormDesigner::WidgetInfo(this);
-        wi->setPixmap("frame");
+        wi->setIconName(koIconName("frame"));
         wi->setClassName("KexiFrame");
         wi->setParentFactoryName("containers");
         wi->setInheritedClassName("QFrame"); /* we are inheriting to get i18n'd strings already translated there */
@@ -161,7 +162,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     }
     {
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("label");
+        wi->setIconName(koIconName("label"));
         wi->setClassName("KexiDBLabel");
         wi->setParentFactoryName("stdwidgets");
         wi->setInheritedClassName("QLabel"); /* we are inheriting to get i18n'd strings already translated there */
@@ -179,7 +180,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
 #ifndef KEXI_NO_IMAGEBOX_WIDGET
     {
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("pixmaplabel");
+        wi->setIconName(koIconName("pixmaplabel"));
         wi->setClassName("KexiDBImageBox");
         wi->setParentFactoryName("stdwidgets");
         wi->setInheritedClassName("KexiPictureLabel"); /* we are inheriting to get i18n'd strings already translated there */
@@ -200,7 +201,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
 #ifdef KEXI_DB_COMBOBOX_WIDGET
     {
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("combo");
+        wi->setIconName(koIconName("combo"));
         wi->setClassName("KexiDBComboBox");
         wi->setParentFactoryName("stdwidgets");
         wi->setInheritedClassName("KComboBox"); /* we are inheriting to get i18n'd strings already translated there */
@@ -215,7 +216,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
 #endif
     {
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("check");
+        wi->setIconName(koIconName("check"));
         wi->setClassName("KexiDBCheckBox");
         wi->setParentFactoryName("stdwidgets");
         wi->setInheritedClassName("QCheckBox"); /* we are inheriting to get i18n'd strings already translated there */
@@ -230,7 +231,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
 #ifndef KEXI_NO_AUTOFIELD_WIDGET
     {
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("autofield");
+        wi->setIconName(koIconName("autofield"));
         wi->setClassName("KexiDBAutoField");
         wi->addAlternateClassName("KexiDBFieldEdit", true/*override*/); //older
         wi->setName(i18n("Auto Field"));
@@ -245,7 +246,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
 
     /*
       KexiDataAwareWidgetInfo *wDate = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KDateWidget");
-      wDate->setPixmap("dateedit");
+      wDate->setIconName(koIconName("dateedit"));
       wDate->setClassName("KexiDBDateEdit");
       wDate->addAlternateClassName("QDateEdit", true);//override
       wDate->addAlternateClassName("KDateWidget", true);//override
@@ -256,7 +257,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
       addClass(wDate);
 
       KexiDataAwareWidgetInfo *wTime = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KTimeWidget");
-      wTime->setPixmap("timeedit");
+      wTime->setIconName(koIconName("timeedit"));
       wTime->setClassName("KexiDBTimeEdit");
       wTime->addAlternateClassName("QTimeEdit", true);//override
       wTime->addAlternateClassName("KTimeWidget", true);//override
@@ -267,7 +268,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
       addClass(wTime);
 
       KexiDataAwareWidgetInfo *wDateTime = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KDateTimeWidget");
-      wDateTime->setPixmap("datetimeedit");
+      wDateTime->setIconName(koIconName("datetimeedit"));
       wDateTime->setClassName("KexiDBDateTimeEdit");
       wDateTime->addAlternateClassName("QDateTimeEdit", true);//override
       wDateTime->addAlternateClassName("KDateTimeWidget", true);//override
@@ -279,7 +280,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     */
 
     /* KexiDataAwareWidgetInfo *wIntSpinBox = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KIntSpinBox");
-      wIntSpinBox->setPixmap("spin");
+      wIntSpinBox->setIconName(koIconName("spin"));
       wIntSpinBox->setClassName("KexiDBIntSpinBox");
       wIntSpinBox->addAlternateClassName("QSpinBox", true);
       wIntSpinBox->addAlternateClassName("KIntSpinBox", true);
@@ -290,7 +291,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
       addClass(wIntSpinBox);
 
       KexiDataAwareWidgetInfo *wDoubleSpinBox = new KexiDataAwareWidgetInfo(this, "stdwidgets");
-      wDoubleSpinBox->setPixmap("spin");
+      wDoubleSpinBox->setIconName(koIconName("spin"));
       wDoubleSpinBox->setClassName("KexiDBDoubleSpinBox");
       wDoubleSpinBox->addAlternateClassName("KDoubleSpinBox", true);
       wDoubleSpinBox->setName(i18n("Floating-point Number Spin Box"));
@@ -315,7 +316,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     {
         KFormDesigner::WidgetInfo* wi = new KFormDesigner::WidgetInfo(this);
         wi->setClassName("KexiDBCommandLinkButton");
-        wi->setPixmap("button");
+        wi->setIconName(koIconName("button"));
         wi->setName(i18n("Link Button"));
         wi->setNamePrefix(
             i18nc("Widget name. This string will be used to name widgets of this class. "
@@ -325,7 +326,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     }
     {
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("slider");
+        wi->setIconName(koIconName("slider"));
         wi->setClassName("KexiDBSlider");
         wi->setName(i18n("Slider"));
         wi->setNamePrefix(
@@ -336,7 +337,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     }
     {
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("progress");
+        wi->setIconName(koIconName("progress"));
         wi->setClassName("KexiDBProgressBar");
         wi->setName(i18n("Progress Bar"));
         wi->setNamePrefix(
@@ -347,7 +348,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     }
     {
         KexiDataAwareWidgetInfo* wi = new KexiDataAwareWidgetInfo(this);
-        wi->setPixmap("dateedit");
+        wi->setIconName(koIconName("dateedit"));
         wi->setClassName("KexiDBDatePicker");
         wi->setName(i18n("Date Picker"));
         wi->setNamePrefix(
@@ -357,8 +358,22 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
         addClass(wi);
     }
 
-    
-
+    m_propDesc["invertedAppearance"] = i18n("Inverted");
+    m_propDesc["minimum"] = i18n("Minimum");
+    m_propDesc["maximum"] = i18n("Maximum");
+    m_propDesc["format"] = i18n("Format");
+    m_propDesc["orientation"] = i18n("Orientation");
+    m_propDesc["textDirection"] = i18n("Text Direction");
+    m_propDesc["textVisible"] = i18n("Text Visible");
+    m_propDesc["value"] = i18n("Value");
+    m_propDesc["date"] = i18n("Date");
+    m_propDesc["arrowVisible"] = i18n("Arrow Visible");
+    m_propDesc["description"] = i18n("Description");
+    m_propDesc["pageStep"] = i18n("Page Step");
+    m_propDesc["singleStep"] = i18n("Single Step");
+    m_propDesc["tickInterval"] = i18n("Tick Interval");
+    m_propDesc["tickPosition"] = i18n("Tick Position");
+    m_propDesc["showEditor"] = i18n("Show Editor");
     m_propDesc["formName"] = i18n("Form Name");
     m_propDesc["onClickAction"] = i18n("On Click");
     m_propDesc["onClickActionOption"] = i18n("On Click Option");
@@ -380,6 +395,13 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     m_propValDesc["ComboBox"] = i18nc("AutoField editor's type", "Drop-Down List");
     m_propValDesc["Image"] = i18nc("AutoField editor's type", "Image");
 
+    m_propValDesc["NoTicks"] = i18n("No Ticks");
+    m_propValDesc["TicksAbove"] = i18n("Above");
+    m_propValDesc["TicksLeft"] = i18n("Left");
+    m_propValDesc["TicksBelow"] = i18n("Below");
+    m_propValDesc["TicksRight"] = i18n("Right");
+    m_propValDesc["TicksBothSides"] = i18n("Both Sides");
+
 // m_propDesc["labelCaption"] = i18n("Label Text");
     m_propDesc["autoCaption"] = i18n("Auto Label");
     m_propDesc["foregroundLabelColor"] = i18n("Label Text Color");
@@ -530,7 +552,7 @@ KexiDBFactory::createCustomActions(KActionCollection* col)
 {
     //this will create shared instance action for design mode (special collection is provided)
     col->addAction("widget_assign_action",
-                   m_assignAction = new KAction(KIcon("form_action"), i18n("&Assign Action..."), this));
+                   m_assignAction = new KAction(koIcon("form_action"), i18n("&Assign Action..."), this));
 }
 
 bool
@@ -588,9 +610,11 @@ KexiDBFactory::startInlineEditing(InlineEditorCreationArguments& args)
         args.text = linkButton->text();
         const QRect r(linkButton->style()->subElementRect(
                         QStyle::SE_PushButtonContents, &option, linkButton));
-        args.geometry = QRect(linkButton->x() + r.x(), linkButton->y() + r.y(), r.width(), r.height());
+
+        QFontMetrics fm(linkButton->font());
+        args.geometry = QRect(linkButton->x() + linkButton->iconSize().width() + 6, linkButton->y() + r.y(), r.width()  - 6, fm.height()+14);
+
         return true;
-        
     }
     else if (args.classname == "KexiDBLabel") {
         KexiDBLabel *label = static_cast<KexiDBLabel*>(args.widget);
@@ -718,6 +742,12 @@ KexiDBFactory::isPropertyVisibleInternal(const QByteArray& classname, QWidget *w
              ;
      } else if (classname == "KexiDBCommandLinkButton") {
         ok = property != "isDragEnabled"
+             && property != "default"
+             && property != "checkable"
+             && property != "autoDefault"
+             && property != "autoRepeat"
+             && property != "autoRepeatDelay"
+             && property != "autoRepeatInterval"
 #ifdef KEXI_NO_UNFINISHED
              && property != "onClickAction" /*! @todo reenable */
              && property != "onClickActionOption" /*! @todo reenable */
@@ -727,9 +757,11 @@ KexiDBFactory::isPropertyVisibleInternal(const QByteArray& classname, QWidget *w
 #endif
              ;
      } else if (classname == "KexiDBSlider") {
-        ok = property != "focusPolicy";
+        ok = property != "sliderPosition"
+             && property != "tracking";
      } else if (classname == "KexiDBProgressBar") {
-        ok = property != "focusPolicy";
+        ok = property != "focusPolicy"
+             && property != "value";
      } else if (classname == "KexiDBLineEdit")
         ok = property != "urlDropsEnabled"
              && property != "vAlign"
@@ -791,6 +823,11 @@ KexiDBFactory::isPropertyVisibleInternal(const QByteArray& classname, QWidget *w
             return false;
         ok = property != "autoRepeat";
     }
+    else if (classname == "KexiDBDatePicker") {
+        ok = property != "closeButton"
+             && property != "fontSize";
+    }
+
 
     return ok && KexiDBFactoryBase::isPropertyVisibleInternal(classname, w, property, isTopLevel);
 }
@@ -820,7 +857,12 @@ bool KexiDBFactory::changeInlineText(KFormDesigner::Form *form, QWidget *widget,
         oldText = widget->property("caption").toString();
         changeProperty(form, widget, "caption", text);
         return true;
+    } else if (n == "KexiDBCommandLinkButton") {
+        oldText = widget->property("text").toString();
+        changeProperty(form, widget, "text", text);
+        return true;
     }
+
 //! @todo check field's geometry
     return false;
 }
