@@ -23,14 +23,16 @@
 #include "kexiprjtypeselector.h"
 #include "kexidbconnectionwidget.h"
 
-#include <kexidb/drivermanager.h>
-#include <kexidb/connectiondata.h>
-#include <kexidb/utils.h>
+#include <db/drivermanager.h>
+#include <db/connectiondata.h>
+#include <db/utils.h>
+#include <kexiutils/utils.h>
 
 #include <core/kexi.h>
 
+#include <KoIcon.h>
+
 #include <kapplication.h>
-#include <kiconloader.h>
 #include <kmimetype.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -57,7 +59,7 @@ public:
     {
         setupUi(this);
         setObjectName("conn_sel");
-        lblIcon->setPixmap(DesktopIcon(KEXI_ICON_DATABASE_SERVER));
+        lblIcon->setPixmap(DesktopIcon(KEXI_DATABASE_SERVER_ICON_NAME));
         lblIcon->setFixedSize(lblIcon->pixmap()->size());
         btn_add->setToolTip(i18n("Add a new database connection"));
         btn_edit->setToolTip(i18n("Edit selected database connection"));
@@ -133,7 +135,7 @@ KexiConnectionSelectorWidget::KexiConnectionSelectorWidget(
     d->conn_set = &conn_set;
     d->startDirOrVariable = startDirOrVariable;
     d->fileAccessType = fileAccessType;
-    QString iconname(KexiDB::defaultFileBasedDriverIcon());
+    QString iconname(KexiDB::defaultFileBasedDriverIconName());
     setWindowIcon(KIcon(iconname));
 
     QBoxLayout* globalLyr = new QVBoxLayout(this);
@@ -162,7 +164,7 @@ KexiConnectionSelectorWidget::KexiConnectionSelectorWidget(
     globalLyr->addWidget(d->stack, 1);
 
 // m_file = new KexiOpenExistingFile( this, "KexiOpenExistingFile");
-// m_file->btn_advanced->setIconSet( KIcon("arrow-down") );
+// m_file->btn_advanced->setIconSet( koIcon("arrow-down") );
     fileWidget = 0;
 
 // addWidget(m_file);
@@ -214,9 +216,6 @@ void KexiConnectionSelectorWidget::slotPrjTypeSelected(int id)
                 //   }
             }
             if (d->remote->list->topLevelItemCount() > 0) {
-                d->remote->list->sortByColumn(0, Qt::AscendingOrder);
-                d->remote->list->resizeColumnToContents(0); // name
-                d->remote->list->resizeColumnToContents(1); // type
                 d->remote->list->topLevelItem(0)->setSelected(true);
             }
             d->remote->descGroupBox->layout()->setMargin(2);
@@ -400,7 +399,7 @@ void KexiConnectionSelectorWidget::slotRemoteAddBtnClicked()
 {
     KexiDB::ConnectionData data;
     KexiDBConnectionDialog dlg(this, data, QString(),
-                               KGuiItem(i18n("&Add"), "dialog-ok", i18n("Add database connection")));
+                               KGuiItem(i18n("&Add"), koIconName("dialog-ok"), i18n("Add database connection")));
     dlg.setWindowTitle(i18n("Add New Database Connection"));
     if (QDialog::Accepted != dlg.exec())
         return;
@@ -429,7 +428,7 @@ void KexiConnectionSelectorWidget::slotRemoteEditBtnClicked()
     if (!item)
         return;
     KexiDBConnectionDialog dlg(this, *item->data(), QString(),
-                               KGuiItem(i18n("&Save"), "document-save",
+                               KGuiItem(i18n("&Save"), koIconName("document-save"),
                                         i18n("Save changes made to this database connection")));
     dlg.setWindowTitle(i18n("Edit Database Connection"));
     if (QDialog::Accepted != dlg.exec())
