@@ -243,6 +243,18 @@ void KisPainter::endTransaction(KisPostExecutionUndoAdapter *undoAdapter)
     d->transaction = 0;
 }
 
+KUndo2Command* KisPainter::endAndTakeTransaction()
+{
+    Q_ASSERT_X(d->transaction, "KisPainter::endTransaction()",
+               "No transaction is in progress");
+
+    KUndo2Command *transactionData = d->transaction->endAndTake();
+    delete d->transaction;
+    d->transaction = 0;
+
+    return transactionData;
+}
+
 void KisPainter::deleteTransaction()
 {
     if (!d->transaction) return;
@@ -1104,6 +1116,11 @@ void KisPainter::paintPainterPath(const QPainterPath& path)
 }
 
 void KisPainter::fillPainterPath(const QPainterPath& path)
+{
+    fillPainterPath(path, QRect());
+}
+
+void KisPainter::fillPainterPath(const QPainterPath& path, const QRect &requestedRect)
 {
     FillStyle fillStyle = d->fillStyle;
 
@@ -1124,16 +1141,15 @@ void KisPainter::fillPainterPath(const QPainterPath& path)
     Q_CHECK_PTR(d->polygon);
 
     QRectF boundingRect = path.boundingRect();
-    QRect fillRect;
-
-    fillRect.setLeft((qint32)floor(boundingRect.left()));
-    fillRect.setRight((qint32)ceil(boundingRect.right()));
-    fillRect.setTop((qint32)floor(boundingRect.top()));
-    fillRect.setBottom((qint32)ceil(boundingRect.bottom()));
+    QRect fillRect = boundingRect.toAlignedRect();
 
     // Expand the rectangle to allow for anti-aliasing.
     fillRect.adjust(-1, -1, 1, 1);
 
+    if (requestedRect.isValid()) {
+        fillRect &= requestedRect;
+    }
+
     // Clip to the image bounds.
     if (d->bounds.isValid()) {
         fillRect &= d->bounds;
@@ -1202,11 +1218,9 @@ void KisPainter::fillPainterPath(const QPainterPath& path)
         }
     }
 
-    QRect r = d->polygon->extent();
-
     // The strokes for the outline may have already added updated the dirtyrect, but it can't hurt,
     // and if we're painting without outlines, then there will be no dirty rect. Let's do it ourselves...
-    bitBlt(r.x(), r.y(), d->polygon, r.x(), r.y(), r.width(), r.height());
+    bitBlt(fillRect.x(), fillRect.y(), d->polygon, fillRect.x(), fillRect.y(), fillRect.width(), fillRect.height());
 }
 
 void KisPainter::drawPainterPath(const QPainterPath& path, const QPen& pen)
@@ -2431,6 +2445,10 @@ void KisPainter::copyMirrorInformation(KisPainter* painter)
     painter->setMirrorInformation(d->axisCenter, d->mirrorHorizontaly, d->mirrorVerticaly);
 }
 
+bool KisPainter::hasMirroring() const
+{
+    return d->mirrorHorizontaly || d->mirrorVerticaly;
+}
 
 void KisPainter::setMaskImageSize(qint32 width, qint32 height)
 {
@@ -2524,41 +2542,6 @@ void KisPainter::renderMirrorMask(QRect rc, KisFixedPaintDeviceSP dab)
 
 }
 
-QVector<QRect> KisPainter::regionsRenderMirrorMask(QRect rc, KisFixedPaintDeviceSP dab)
-{
-    QVector<QRect> region;
-    int x = rc.topLeft().x();
-    int y = rc.topLeft().y();
-
-    int mirrorX = -((x+rc.width()) - d->axisCenter.x()) + d->axisCenter.x();
-    int mirrorY = -((y+rc.height()) - d->axisCenter.y()) + d->axisCenter.y();
-
-    if (d->mirrorHorizontaly && d->mirrorVerticaly){
-        dab->mirror(true, false);
-        bltFixed(mirrorX, y, dab, 0,0,rc.width(),rc.height());
-        region.append( QRect(QPoint(mirrorX,y),rc.size()) );
-
-        dab->mirror(false,true);
-        bltFixed(mirrorX, mirrorY, dab, 0,0,rc.width(),rc.height());
-        region.append( QRect(QPoint(mirrorX,mirrorY),rc.size()) );
-
-        dab->mirror(true, false);
-        bltFixed(x, mirrorY, dab, 0,0,rc.width(),rc.height());
-        region.append( QRect(QPoint(x,mirrorY),rc.size()) );
-
-    }else if (d->mirrorHorizontaly){
-        dab->mirror(true, false);
-        bltFixed(mirrorX, y, dab, 0,0,rc.width(),rc.height());
-        region.append( QRect(QPoint(mirrorX,y),rc.size()) );
-    }else if (d->mirrorVerticaly){
-        dab->mirror(false, true);
-        bltFixed(x, mirrorY, dab, 0,0,rc.width(),rc.height());
-        region.append( QRect(QPoint(x,mirrorY),rc.size()) );
-    }
-    return region;
-}
-
-
 void KisPainter::renderMirrorMask(QRect rc, KisFixedPaintDeviceSP dab, KisFixedPaintDeviceSP mask)
 {
     int x = rc.topLeft().x();
@@ -2619,3 +2602,55 @@ void KisPainter::renderMirrorMask(QRect rc, KisPaintDeviceSP dab, int sx, int sy
     }
 }
 
+void KisPainter::renderDabWithMirroringNonIncremental(QRect rc, KisPaintDeviceSP dab)
+{
+    QVector<QRect> rects;
+
+    int x = rc.topLeft().x();
+    int y = rc.topLeft().y();
+    int mirrorX = -((x+rc.width()) - d->axisCenter.x()) + d->axisCenter.x();
+    int mirrorY = -((y+rc.height()) - d->axisCenter.y()) + d->axisCenter.y();
+
+    rects << rc;
+
+    if (d->mirrorHorizontaly && d->mirrorVerticaly){
+        rects << QRect(mirrorX, y, rc.width(), rc.height());
+        rects << QRect(mirrorX, mirrorY, rc.width(), rc.height());
+        rects << QRect(x, mirrorY, rc.width(), rc.height());
+    } else if (d->mirrorHorizontaly) {
+        rects << QRect(mirrorX, y, rc.width(), rc.height());
+    } else if (d->mirrorVerticaly) {
+        rects << QRect(x, mirrorY, rc.width(), rc.height());
+    }
+
+    foreach(const QRect &rc, rects) {
+        d->device->clear(rc);
+    }
+
+    QRect resultRect = dab->extent() | rc;
+    bool intersects = false;
+
+    for (int i = 1; i < rects.size(); i++) {
+        if (rects[i].intersects(resultRect)) {
+            intersects = true;
+            break;
+        }
+    }
+
+    /**
+     * If there are no cross-intersections, we can use a fast path
+     * and do no cycling recompositioning
+     */
+    if (!intersects) {
+        rects.resize(1);
+    }
+
+    foreach(const QRect &rc, rects) {
+        bitBlt(rc.topLeft(), dab, rc);
+    }
+
+    foreach(const QRect &rc, rects) {
+        renderMirrorMask(rc, dab);
+    }
+}
+
