@@ -73,6 +73,15 @@ public:
     }
 
     ~SelectionManagerTester() {
+        /**
+         * Here is a weird way of precessing pending events.
+         * This is needed for the dummies facade could process
+         * all the queued events telling it some nodes were
+         * added/deleted
+         */
+        QApplication::processEvents();
+        QTest::qSleep(500);
+        QApplication::processEvents();
         delete shell;
         delete doc;
         delete part;
@@ -112,6 +121,11 @@ public:
         return checkOneLayer(image, mask, name);
     }
 
+    bool checkNoSelection() {
+        KisNodeSP mask = findNode(image->root(), "selection");
+        return !mask && !image->globalSelection();
+    }
+
     KisImageSP image;
     KisSelectionManager *selectionManager;
     KisSurrogateUndoStore *undoStore;
@@ -227,15 +241,14 @@ void KisSelectionManagerTest::testDeselectReselect()
 
     t.selectionManager->deselect();
     t.image->waitForDone();
-    QVERIFY(t.checkSelectionOnly("select_all"));
+    QVERIFY(t.checkNoSelection());
 
     t.checkUndo();
     t.startConcurrentTask();
 
     t.selectionManager->deselect();
     t.image->waitForDone();
-    QVERIFY(t.checkSelectionOnly("select_all"));
-
+    QVERIFY(t.checkNoSelection());
 
     t.selectionManager->reselect();
     t.image->waitForDone();
@@ -243,7 +256,7 @@ void KisSelectionManagerTest::testDeselectReselect()
 
     t.undoStore->undo();
     t.image->waitForDone();
-    QVERIFY(t.checkSelectionOnly("select_all"));
+    QVERIFY(t.checkNoSelection());
 
     t.startConcurrentTask();
 
