@@ -27,9 +27,11 @@
 
 #include <kiconloader.h>
 
+#include <KWPart.h>
 #include <KoDockRegistry.h>
 #include <KoDocumentRdfBase.h>
 #include <KoToolRegistry.h>
+#include <KoMainWindow.h>
 
 #ifdef SHOULD_BUILD_RDF
 #include <rdf/KoDocumentRdf.h>
@@ -64,9 +66,11 @@ QObject* KWFactory::create(const char* /*iface*/, QWidget* /*parentWidget*/, QOb
     Q_UNUSED(args);
     Q_UNUSED(keyword);
 
-    KWDocument *doc = new KWDocument(parent);
+    KWPart *part = new KWPart(parent);
+    KWDocument *doc = new KWDocument(part);
+    part->setDocument(doc);
     KoToolRegistry::instance()->add(new KWPageToolFactory());
-    return doc;
+    return part;
 }
 
 KAboutData *KWFactory::aboutData()
@@ -92,7 +96,8 @@ const KComponentData &KWFactory::componentData()
         KoDockRegistry *dockRegistry = KoDockRegistry::instance();
         dockRegistry->add(new KWStatisticsDockerFactory());
 #ifdef SHOULD_BUILD_RDF
-// TODO reenable after release        dockRegistry->add(new KWRdfDockerFactory());
+// TODO reenable after release
+        dockRegistry->add(new KWRdfDockerFactory());
 #endif
 
     }
